@@ -7,7 +7,6 @@ Simple redis-backed, distributed sorted sets.
 
 """
 
-__version__ = '0.4.2'
+__version__ = '0.5'
 
 from redset.sets import *
-import serializers
